@@ -27,7 +27,7 @@ OC.L10N.register(
     "Update interval" : "Intervalu d'anovamientu",
     "Use system cron for updates" : "Usar el cron del sistema pa los anovamientos",
     "No article selected" : "Nun se seleicionó nengún artículu",
-    "Please select an article from the list..." : "Seleiciona un artículu de la llista…",
+    "Show all articles" : "Amosar tolos artículos",
     "Move" : "Mover",
     "Share" : "Compartir",
     "Share with" : "Compartir con",
@@ -41,7 +41,6 @@ OC.L10N.register(
     "Settings" : "Configuración",
     "Documentation" : "Documentación",
     "Keyboard shortcuts" : "Atayos del tecláu",
-    "Show all articles" : "Amosar tolos artículos",
     "Rename" : "Renomar",
     "Delete" : "Desaniciar",
     "Rename Feed" : "Renomar el feed",
@@ -53,16 +52,15 @@ OC.L10N.register(
     "Default order" : "Orde predetermináu",
     "Enable full text" : "Activar el testu completu",
     "Disable full text" : "Desactivar el testu completu",
-    "Previous" : "Anterior",
-    "Next" : "Siguiente",
     "by" : "por",
     "Play audio" : "Reproducir l'audiu",
     "Download audio" : "Baxar l'audiu",
     "Download video" : "Baxar el videu",
     "Open website" : "Abrir el sitiu web",
-    "Not available" : "Nun ta disponible",
     "Please wait" : "Espera",
     "Title" : "Títulu",
+    "Folder" : "Carpeta",
+    "Not available" : "Nun ta disponible",
     "Keyboard shortcut" : "Atayos del tecláu",
     "Action" : "Aición",
     "Refresh" : "Anovar",
@@ -73,7 +71,6 @@ OC.L10N.register(
     "All Articles" : "Tolos artículos",
     "Subscribe to" : "Soscribise a",
     "Unread Articles" : "Artículos ensin lleer",
-    "If given, this service" : "Si s'apurre, esti serviciu",
     "How to set up the operating system cron" : "Cómo configurar el cron del sistema operativu"
 },
 "nplurals=2; plural=(n != 1);");
